<?php
namespace Concrete\Package\EnlilNavTargetAttribute;

defined('C5_EXECUTE') or die('Access Denied.');

use Concrete\Core\Attribute\SetFactory;
use Concrete\Core\Package\Package;
use Concrete\Core\Entity\Attribute\Key\PageKey;
use Concrete\Core\Entity\Attribute\Key\Settings\SelectSettings;
use Concrete\Core\Entity\Attribute\SetKey;
use Concrete\Core\Entity\Attribute\Value\Value\SelectValueOption;
use Concrete\Core\Entity\Attribute\Value\Value\SelectValueOptionList;
use Concrete\Core\Database\DatabaseManagerORM;
use Concrete\Core\Attribute\Category\CategoryService;

class Controller extends Package {
	
	protected $pkgHandle = 'enlil_nav_target_attribute';
	protected $appVersionRequired = '8.5.2'; //8.3.0
	protected $pkgVersion = '0.9.0.0';
	
	public function getPackageName() {
		return t('Enlil Nav Target Attribute');
	}
	
	public function getPackageDescription() {
		return t('Install Nav Target (nav_target) Collection Attribute For Use With Page List Blocks.');
	}
	
	public function install() {
		$pkg = parent::install();
		$this->installPackage($pkg);
	}
	
	public function upgrade() {
		$pkg = $this;
		parent::upgrade();
		$this->installPackage($pkg);
	}
	
	private function installPackage($pkg) {
		$this->installCollectionAttributes($pkg);
	}
	
	private function installCollectionAttributes($pkg) {
		$category = $this->app->make(CategoryService::class)->getByHandle('collection');
		$cat = $category->getController();
		$ak = $cat->getAttributeKeyByHandle('nav_target');
		if (!is_object($ak)) {
			$pk = new PageKey();
			$pk->setAttributeKeyName('Nav Target');
			$pk->setAttributeKeyHandle('nav_target');
			$pk->setIsAttributeKeySearchable(true);
			$pk->setAttributeKeySettings(['akHideNoneOption', 'true']);
			$pk = $cat->add('select', $pk, $this->getSettings(['_self', '_blank', '_parent', '_top']) , $pkg);
			$this->addToSet($pk, 'navigation');
		}
	}
	
	private function getSettings($options){
		$settings = new SelectSettings();
		$list = new SelectValueOptionList();
		$list->setOptions($this->getOptions($options, $list));
		$settings->setHideNoneOption(true);
		$settings->setOptionList($list);
		return $settings;
	}
	
	private function getOptions($options, $list){
		$o = array();
		$order = 0;
		foreach ($options as $option){
			$opt = new SelectValueOption();
			$opt->setSelectAttributeOptionValue($option);
			$opt->setDisplayOrder($order);
			$opt->setOptionList($list);
			if (is_object($opt)) {
				$o[] = $opt;
				++$order;
			}
		}
		return $o;
	}
	
	private function addToSet($key, $attSet = '') {
		if (!empty($attSet)) {
			$set = $this->app->make(SetFactory::class)->getByHandle($attSet);
			if (is_object($set)) {
				$em = $this->app->make(DatabaseManagerORM::class)->entityManager();
				$em->refresh($set);
				$order = 0;
				foreach ($set->getAttributeKeyCollection() as $i) { ++$order; }
				$setKey = new SetKey();
				$setKey->setAttributeKey($key);
				$setKey->setAttributeSet($set);
				$setKey->setDisplayOrder($order);
				$em->persist($setKey);
				$em->flush();
			}
		}
		return;
	}
	
}
